export declare namespace Utils {
    type ToArray<T> = T extends any[] ? T : [T];
    type Callback<T = void, A = any[], R = unknown> = (this: T, ...args: ToArray<A>) => R;
    type DebounceCallback = Callback;
    interface DebounceWrapper<T extends DebounceCallback> {
        (...args: Parameters<T>): void;
        delay: number;
    }
    type ThrottleCallback = Callback<any>;
    interface ThrottleWrapper<T extends ThrottleCallback> {
        (...args: Parameters<T>): ReturnType<T> | void;
        threshold: number;
        lastCallTime: number;
    }
    type CacheWrapper<T extends Callback<any>> = Callback<ThisParameterType<T>, Parameters<T>, ReturnType<T>> & {
        cache: Map<string, ReturnType<T>>;
    };
}
export declare const Utils: {
    readonly Const: {
        readonly EMPTY_OBJECT: {};
        readonly DOUBLE_PI: number;
        readonly HALF_PI: number;
        readonly TRANSPARENT: "rgba(0,0,0,0)";
        readonly IS_TOUCH_MODE: boolean;
    };
    readonly removeIndex: (array: unknown[], index: number) => void;
    readonly insert: <T = unknown>(array: T[], index: number, item: T) => void;
    readonly mix: (a: number, b: number, k: number) => number;
    readonly random: (min: number, max: number) => number;
    readonly pick: <T_1 = unknown>(options: T_1[]) => T_1;
    readonly rad2deg: (rad: number) => number;
    readonly deg2rad: (deg: number) => number;
    readonly quadraticSum: (a: number, b: number) => number;
    readonly distance: (x1: number, y1: number, x2: number, y2: number) => number;
    readonly debounce: (<T_2 extends Utils.Callback<void, any[], unknown>>(callback: T_2, delay?: number | undefined) => Utils.DebounceWrapper<T_2>) & {
        defaultDelay: number;
    };
    readonly throttle: (<T_3 extends Utils.Callback<any, any[], unknown>>(callback: T_3, threshold?: number | undefined) => Utils.ThrottleWrapper<T_3>) & {
        defaultThreshold: number;
    };
    readonly cache: <T_4 extends Utils.Callback<any, any[], unknown>>(fn: T_4) => Utils.CacheWrapper<T_4>;
};
