import { Renderable } from "../core/Renderer";
import { VectorLike, Vector } from "../common/Vector";
import { CommonStyle, StrokeStyle, FillStyle } from "./Style";
export interface Projection {
    min: number;
    max: number;
}
export interface ShapeLike extends Renderable {
    project(direction: VectorLike): Projection;
}
export declare type ShapeStyle = CommonStyle & StrokeStyle & FillStyle;
export declare type ShapeProps = Partial<{
    position: Vector;
    rotation: number;
    style: Partial<ShapeStyle>;
    fillFirst: boolean;
}>;
export declare abstract class Shape implements Required<ShapeProps>, ShapeLike {
    static defaults: ShapeProps;
    constructor(props?: ShapeProps);
    position: Vector;
    rotation: number;
    style: Partial<ShapeStyle>;
    fillFirst: boolean;
    abstract path(context: CanvasRenderingContext2D): void;
    abstract project(direction: VectorLike): Projection;
    render(context: CanvasRenderingContext2D): void;
}
